﻿using Newtonsoft.Json.Linq;
using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Net;
using System.Net.Http;
using System.Net.Http.Headers;
using System.Text;
using Silanis.ESL.SDK;
using Silanis.ESL.SDK.Builder;
using System.IO;

class docAttachments
{
    //replace api_key placeholder with your own value
    public static string API_KEY = "api_key";
    public static string API_URL = "https://sandbox.e-signlive.com/api";

    public static void Main(string[] args)
    {
        EslClient client = new EslClient(API_KEY, API_URL);

        DocumentPackage attachToPackage = PackageBuilder.NewPackageNamed("Attachment Package Example")
                            .WithSigner(SignerBuilder.NewSignerWithEmail("esl.signer1@example.com")
                                    .WithFirstName("Haris")
                                    .WithLastName("Haidary")
                                    .WithCustomId("Preparer1")
                                    .DeliverSignedDocumentsByEmail())
                            .WithSigner(SignerBuilder.NewSignerWithEmail("esl.signer2@example.com")
                                    .WithFirstName("John")
                                    .WithLastName("Doe")
                                    .WithCustomId("Signer1")
                                    .DeliverSignedDocumentsByEmail()
                                    .WithAttachmentRequirement(AttachmentRequirementBuilder.NewAttachmentRequirementWithName("Driver's license")
                                        .WithDescription("Mandatory")
                                        .IsRequiredAttachment()
                                        .Build()))
                            .WithDocument(DocumentBuilder.NewDocumentNamed("sample_nda")
                                    .FromFile(@"DOC_FILE_PATH")
                                    .EnableExtraction()
                                    .WithId("documentId")
                                    .WithDescription("sample Non-Disclosure Agreement"))
                            .Build();

        client.CreateAndSendPackage(attachToPackage);


        PackageId packageId = new PackageId("0c0b8716-5762-47b5-903e-4aef464625e0");
        DocumentPackage myPackage = client.GetPackage(packageId);
        Signer signer1 = myPackage.GetSigner("esl.signer1@example.com");


        //Retrieve attachment status
        IList<AttachmentRequirement> signer1Attachments = myPackage.GetSigner("esl.signer1@example.com").Attachments;

        foreach (AttachmentRequirement attachment in signer1Attachments)
        {
            Debug.WriteLine(attachment.Name + " " + attachment.Status + " " + attachment.Id);
        }

        //Download all attachments
        DownloadedFile downloadedAttachment = client.AttachmentRequirementService.DownloadAttachmentFile(packageId, "xI6AATNjp7AA");
        System.IO.File.WriteAllBytes(downloadedAttachment.Filename, downloadedAttachment.Contents);

        DownloadedFile downloadedAllAttachmentsForPackage = client.AttachmentRequirementService.DownloadAllAttachmentFilesForPackage(packageId);
        System.IO.File.WriteAllBytes("all_attachments_in_package.zip", downloadedAllAttachmentsForPackage.Contents);

        DownloadedFile downloadedAllAttachmentsForSigner1InPackage = client.AttachmentRequirementService.DownloadAllAttachmentFilesForSignerInPackage(myPackage, signer1);
        System.IO.File.WriteAllBytes("signer1_attachments.zip", downloadedAllAttachmentsForSigner1InPackage.Contents);

        //Accept attachment
        client.AttachmentRequirementService.AcceptAttachment(packageId, signer1, "Driver's license");

        //Reject attachment
        client.AttachmentRequirementService.RejectAttachment(packageId, signer1, "Driver's license", "Expired driver's license");

    }
}